@@ -5,6 +5,9 @@ from .correlate_delay import remove_lag
 from .spectrum_analysis import Spec
 from . import eddyqc
 from .eddyqc import *
+from .import eddyspec
+from .eddyspec import *
 
 __all__ = ["Raw", "despikeVM", "rotate_wind", "remove_lag", "Spec"]
-__all__ += eddyqc.__all__
\ No newline at end of file
+__all__ += eddyqc.__all__
+__all__ += eddyspec.__all__
\ No newline at end of file
