@@ -6,12 +6,12 @@ from datetime import datetime, timedelta
 from .qcutils import stats4qc, iqr_qc, glbdec, despike, detrend, deplatform
 from .CO2 import center_rolling, retuning, qc_CO2
 from .Ts import get_minute_std, qc_Ts
-from .mutual import two_systems
+from .mutual import two_systems, two_systems2, user_rolling_qc
 
 __all__ = [
     'np', 'pd', 'plt', 'Path', 'datetime', 'timedelta',
     'stats4qc', 'iqr_qc', 'glbdec', 'despike', 'detrend', 'deplatform',
     'center_rolling', 'retuning', 'qc_CO2',
     'get_minute_std', 'qc_Ts',
-    'two_systems'
+    'two_systems', 'two_systems2', 'user_rolling_qc'
     ]
\ No newline at end of file
